@@ -1,4 +1,6 @@
 from django.conf import settings
+from django.contrib.auth.decorators import login_required, user_passes_test
+from django.utils.decorators import method_decorator
 from django.views.generic import TemplateView
 
 from .utils import LogManager
@@ -9,6 +11,11 @@ manager = LogManager()
 class LogHome(TemplateView):
     template_name = 'log_viewer/log_home.html'
 
+    @method_decorator(login_required)
+    @method_decorator(user_passes_test(lambda user: user.is_superuser))
+    def dispatch(self, request, *args, **kwargs):
+        return super(LogHome, self).dispatch(request, *args, **kwargs)
+
     def get_context_data(self, **kwargs):
         context = super(LogHome, self).get_context_data(**kwargs)
         context['site_name'] = getattr(settings, 'SITE_NAME', 'LogViewer')
